.. currentmodule:: sardana.tango.core.SardanaDevice

:mod:`~sardana.tango.core.SardanaDevice`
==============================================

.. automodule:: sardana.tango.core.SardanaDevice

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`SardanaDevice`
    * :class:`SardanaDeviceClass`


SardanaDevice
--------------

.. inheritance-diagram:: SardanaDevice
    :parts: 1
    
.. autoclass:: SardanaDevice
    :show-inheritance:
    :members:
    :undoc-members:

SardanaDeviceClass
-------------------

.. inheritance-diagram:: SardanaDeviceClass
    :parts: 1
    
.. autoclass:: SardanaDeviceClass
    :show-inheritance:
    :members:
    :undoc-members:

